<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>AuthenticationWidget</name>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="15"/>
        <source>Username:</source>
        <translation>Nom d&apos;usuari:</translation>
    </message>
    <message>
        <location filename="../src/GUI/authenticationwidget.cpp" line="16"/>
        <source>Password:</source>
        <translation>Contrasenya:</translation>
    </message>
</context>
<context>
    <name>CadenceGraph</name>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="11"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="12"/>
        <location filename="../src/GUI/cadencegraph.h" line="16"/>
        <source>Cadence</source>
        <translation>Cadència</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Màx</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
</context>
<context>
    <name>CadenceGraphItem</name>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="18"/>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="20"/>
        <source>rpm</source>
        <translation>rpm</translation>
    </message>
    <message>
        <location filename="../src/GUI/cadencegraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
</context>
<context>
    <name>Data</name>
    <message>
        <location filename="../src/data/data.cpp" line="160"/>
        <source>Supported files</source>
        <translation>Fitxers compatibles</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="161"/>
        <source>CSV files</source>
        <translation>Fitxers CSV</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="162"/>
        <source>CUP files</source>
        <translation>Fitxers CUP</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="163"/>
        <source>FIT files</source>
        <translation>Fitxers FIT</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="164"/>
        <source>GeoJSON files</source>
        <translation>Fitxers GeoJSON</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="165"/>
        <source>GPI files</source>
        <translation>Fitxers GPI</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="166"/>
        <source>GPX files</source>
        <translation>Fitxers GPX</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="167"/>
        <source>IGC files</source>
        <translation>Fitxers IGC</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="168"/>
        <source>ITN files</source>
        <translation>Fitxers ITN</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="169"/>
        <source>JPEG images</source>
        <translation>Imatges JPEG</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="170"/>
        <source>KML files</source>
        <translation>Fitxers KML</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="171"/>
        <source>LOC files</source>
        <translation>Fitxers LOC</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="172"/>
        <source>NMEA files</source>
        <translation>Fitxers NMEA</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="173"/>
        <source>ONmove files</source>
        <translation>Fitxer ONmove</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="174"/>
        <source>OV2 files</source>
        <translation>Fitxers OV2</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="175"/>
        <source>OziExplorer files</source>
        <translation>Fitxers OziExplorer</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="176"/>
        <source>SLF files</source>
        <translation>Fitxers SLF</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="177"/>
        <source>SML files</source>
        <translation>Fitxers SML</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="178"/>
        <source>TCX files</source>
        <translation>Fitxers TCX</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="179"/>
        <source>TwoNav files</source>
        <translation>Fitxers TwoNav</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="180"/>
        <source>GPSDump files</source>
        <translation>Ffitxers d&apos;abocament de GPS</translation>
    </message>
    <message>
        <location filename="../src/data/data.cpp" line="181"/>
        <source>All files</source>
        <translation>Tots els fitxers</translation>
    </message>
</context>
<context>
    <name>DirSelectWidget</name>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="18"/>
        <source>System default</source>
        <translation>Predeterminat pel sistema</translation>
    </message>
    <message>
        <location filename="../src/GUI/dirselectwidget.cpp" line="40"/>
        <source>Select directory</source>
        <translation>Escull directori</translation>
    </message>
</context>
<context>
    <name>ElevationGraph</name>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="39"/>
        <location filename="../src/GUI/elevationgraph.h" line="16"/>
        <source>Elevation</source>
        <translation>Elevació</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="59"/>
        <source>Up</source>
        <extracomment>Use an Unicode arrow (U+2197) when there is no abbreviation or extremly short term for &quot;Up&quot; in your language</extracomment>
        <translation>Amunt</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="63"/>
        <source>Down</source>
        <extracomment>Use an Unicode arrow (U+2198) when there is no abbreviation or extremly short term for &quot;Down&quot; in your language</extracomment>
        <translation>Avall</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="66"/>
        <source>Max</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Màx</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="69"/>
        <source>Min</source>
        <extracomment>Use an abbreviation or a extremly short term</extracomment>
        <translation>Mín</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="72"/>
        <source>Ascent</source>
        <translation>Pujada</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="74"/>
        <source>Descent</source>
        <translation>Baixada</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="76"/>
        <source>Maximum</source>
        <translation>Màxim</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="78"/>
        <source>Minimum</source>
        <translation>Mínim</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="181"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraph.cpp" line="184"/>
        <source>ft</source>
        <translation>peus</translation>
    </message>
</context>
<context>
    <name>ElevationGraphItem</name>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="33"/>
        <source>ft</source>
        <translation>peus</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="36"/>
        <source>Ascent</source>
        <translation>Pujada</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="38"/>
        <source>Descent</source>
        <translation>Baixada</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="40"/>
        <source>Maximum</source>
        <translation>Màxim</translation>
    </message>
    <message>
        <location filename="../src/GUI/elevationgraphitem.cpp" line="42"/>
        <source>Minimum</source>
        <translation>Mínim</translation>
    </message>
</context>
<context>
    <name>FileSelectWidget</name>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="46"/>
        <location filename="../src/GUI/fileselectwidget.cpp" line="51"/>
        <source>Select file</source>
        <translation>Escull fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="61"/>
        <source>No output file selected.</source>
        <translation>Cap fitxer de sortida seleccionat.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="71"/>
        <source>%1 is a directory.</source>
        <translation>%1 és un directori.</translation>
    </message>
    <message>
        <location filename="../src/GUI/fileselectwidget.cpp" line="75"/>
        <source>%1 is not writable.</source>
        <translation>%1 només de lectura.</translation>
    </message>
</context>
<context>
    <name>Format</name>
    <message>
        <location filename="../src/GUI/format.cpp" line="54"/>
        <location filename="../src/GUI/format.cpp" line="61"/>
        <location filename="../src/GUI/format.cpp" line="84"/>
        <source>ft</source>
        <translation>peus</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="57"/>
        <source>mi</source>
        <translation>milles</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="64"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="68"/>
        <location filename="../src/GUI/format.cpp" line="81"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/format.cpp" line="71"/>
        <source>km</source>
        <translation>km</translation>
    </message>
</context>
<context>
    <name>GUI</name>
    <message>
        <location filename="../src/GUI/gui.cpp" line="199"/>
        <source>Quit</source>
        <translation>Sortir</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="207"/>
        <location filename="../src/GUI/gui.cpp" line="951"/>
        <location filename="../src/GUI/gui.cpp" line="969"/>
        <source>Paths</source>
        <translation>Camins</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="211"/>
        <location filename="../src/GUI/gui.cpp" line="911"/>
        <location filename="../src/GUI/gui.cpp" line="912"/>
        <source>Keyboard controls</source>
        <translation>Controls del teclat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="215"/>
        <location filename="../src/GUI/gui.cpp" line="878"/>
        <source>About GPXSee</source>
        <translation>Sobre GPXSee</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="221"/>
        <source>Open...</source>
        <translation>Obrir...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="228"/>
        <source>Open directory...</source>
        <translation>Obrir directori...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="233"/>
        <source>Print...</source>
        <translation>Imprimir...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="239"/>
        <source>Export to PDF...</source>
        <translation>Exportar a PDF...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="246"/>
        <source>Export to PNG...</source>
        <translation>Exportar a PNG...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="253"/>
        <source>Close</source>
        <translation>Tancar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="260"/>
        <source>Reload</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="266"/>
        <source>Statistics...</source>
        <translation>Estadístiques...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="276"/>
        <source>Clear list</source>
        <translation>Esborrar la llista</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="288"/>
        <source>Load POI file...</source>
        <translation>Carregar arxiu POI...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="292"/>
        <source>Select all files</source>
        <translation>Seleccionar tots els fitxers</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="297"/>
        <source>Unselect all files</source>
        <translation>Deseleccionar tots els fitxers</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="302"/>
        <source>Overlap POIs</source>
        <translation>Sobreposar POIs</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="307"/>
        <source>Show POI icons</source>
        <translation>Mostra icones POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="312"/>
        <source>Show POI labels</source>
        <translation>Mostra etiquetes POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="318"/>
        <source>Show POIs</source>
        <translation>Mostra POIs</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="330"/>
        <source>Show map</source>
        <translation>Mostra el mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="339"/>
        <source>Load map...</source>
        <translation>Carrega el mapa...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="344"/>
        <source>Load map directory...</source>
        <translation>Carrega directori de mapes...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="347"/>
        <source>Clear tile cache</source>
        <translation>Buida la memòria de tessel·les</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="352"/>
        <location filename="../src/GUI/gui.cpp" line="357"/>
        <location filename="../src/GUI/gui.cpp" line="930"/>
        <source>Next map</source>
        <translation>Següent mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="362"/>
        <source>Show cursor coordinates</source>
        <translation>Mostra les coordenades del cursor</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="370"/>
        <source>Show position</source>
        <translation>Mostra la posició</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="376"/>
        <source>Follow position</source>
        <translation>Segueix la posició</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="381"/>
        <source>Show coordinates</source>
        <translation>Mostra les coordenades</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="387"/>
        <source>Show motion info</source>
        <translation>Mostra informació de moviment</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="394"/>
        <source>Show tracks</source>
        <translation>Mostra les traces</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="399"/>
        <source>Show routes</source>
        <translation>Mostra les rutes</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="403"/>
        <source>Show waypoints</source>
        <translation>Mostra els punts de pas</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="408"/>
        <source>Show areas</source>
        <translation>Mostra les àrees</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="412"/>
        <source>Waypoint icons</source>
        <translation>Icones de punts de pas</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="417"/>
        <source>Waypoint labels</source>
        <translation>Etiquetes de punts de pas</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="422"/>
        <source>Route waypoints</source>
        <translation>Punts de pas de ruta</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="427"/>
        <source>km/mi markers</source>
        <translation>Fites km/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="435"/>
        <source>Do not show</source>
        <translation>No mostris</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="439"/>
        <source>Marker only</source>
        <translation>Només marcador</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="443"/>
        <source>Date/time</source>
        <translation>Data i hora</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="447"/>
        <source>Coordinates</source>
        <translation>Coordenades</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="451"/>
        <source>Use styles</source>
        <translation>Empra estils</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="458"/>
        <source>Download data DEM</source>
        <translation>Descarregar dades DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="464"/>
        <source>Download map DEM</source>
        <translation>Descarregar mapa DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="469"/>
        <source>Show local DEM tiles</source>
        <translation>Mostra tessel·les DEM locals</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="472"/>
        <source>Show hillshading</source>
        <translation>Mostra l&apos;ombrejat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="480"/>
        <source>Show graphs</source>
        <translation>Mostra gràfiques</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="488"/>
        <location filename="../src/GUI/gui.cpp" line="1370"/>
        <location filename="../src/GUI/gui.cpp" line="1430"/>
        <source>Distance</source>
        <translation>Distància</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="495"/>
        <location filename="../src/GUI/gui.cpp" line="740"/>
        <location filename="../src/GUI/gui.cpp" line="1372"/>
        <location filename="../src/GUI/gui.cpp" line="1432"/>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="501"/>
        <source>Show grid</source>
        <translation>Mostra malla</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="506"/>
        <source>Show slider info</source>
        <translation>Mostra informació lliscant</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="512"/>
        <source>Show tabs</source>
        <translation>Mostra pestanyes</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="521"/>
        <source>Show toolbars</source>
        <translation>Mostra les barres d&apos;eines</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="528"/>
        <source>Total time</source>
        <translation>Temps total</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="533"/>
        <location filename="../src/GUI/gui.cpp" line="1373"/>
        <location filename="../src/GUI/gui.cpp" line="1434"/>
        <source>Moving time</source>
        <translation>Temps en moviment</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="540"/>
        <source>Metric</source>
        <translation>Mètric</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="545"/>
        <source>Imperial</source>
        <translation>Imperial</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="551"/>
        <source>Nautical</source>
        <translation>Nàutic</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="559"/>
        <source>Decimal degrees (DD)</source>
        <translation>Graus decimals (DD)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="565"/>
        <source>Degrees and decimal minutes (DMM)</source>
        <translation>Graus i minuts decimals (DMM)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="572"/>
        <source>Degrees, minutes, seconds (DMS)</source>
        <translation>Graus, minuts, segons (DMS)</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="579"/>
        <source>Fullscreen mode</source>
        <translation>Mode de pantalla completa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="586"/>
        <source>Options...</source>
        <translation>Opcions...</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="593"/>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="598"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="603"/>
        <source>Last</source>
        <translation>Darrer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="608"/>
        <source>First</source>
        <translation>Primer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="643"/>
        <source>&amp;File</source>
        <translation>&amp;Fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="646"/>
        <source>Open recent</source>
        <translation>Obert fa poc</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="671"/>
        <source>&amp;Map</source>
        <translation>&amp;Mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="681"/>
        <source>&amp;Graph</source>
        <translation>&amp;Gràfic</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="693"/>
        <source>&amp;Data</source>
        <translation>&amp;Dades</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="698"/>
        <source>Position info</source>
        <translation>Informació de la posició</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="712"/>
        <source>&amp;POI</source>
        <translation>&amp;POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="724"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="732"/>
        <source>Position</source>
        <translation>Posició</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="739"/>
        <source>&amp;Settings</source>
        <translation>&amp;Configuració</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="744"/>
        <source>Units</source>
        <translation>Unitats</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="749"/>
        <source>Coordinates format</source>
        <translation>Format de coordenades</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="762"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="789"/>
        <source>File</source>
        <translation>Fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="799"/>
        <source>Show</source>
        <translation>Mostra</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="807"/>
        <source>Navigation</source>
        <translation>Navegació</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="880"/>
        <location filename="../src/GUI/gui.cpp" line="888"/>
        <source>Version %1</source>
        <translation>Versió %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="883"/>
        <location filename="../src/GUI/gui.cpp" line="892"/>
        <source>GPXSee is distributed under the terms of the GNU General Public License version 3. For more info about GPXSee visit the project homepage at %1.</source>
        <translation>GPXSee es distribueix sota els termes de la Llicència Pública General de GNU versió 3. Per a més informació sobre GPXSee visiteu la web del projecte a %1.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="915"/>
        <source>Next file</source>
        <translation>Següent fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="916"/>
        <source>Previous file</source>
        <translation>Fitxer anterior</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="918"/>
        <source>First file</source>
        <translation>Primer fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="920"/>
        <source>Last file</source>
        <translation>Darrer fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="921"/>
        <source>Append file</source>
        <translation>Afegeix un fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="922"/>
        <source>Next/Previous</source>
        <translation>Següent/Anterior</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="924"/>
        <source>Toggle graph type</source>
        <translation>Canvia el tipus de gràfic</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="926"/>
        <source>Toggle time type</source>
        <translation>Canvia el tipus de temps</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="928"/>
        <source>Toggle position info</source>
        <translation>Commuta la informació de la posició</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="932"/>
        <source>Previous map</source>
        <translation>Mapa anterior</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="933"/>
        <source>Zoom in</source>
        <translation>Apropar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="935"/>
        <source>Zoom out</source>
        <translation>Allunyar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="937"/>
        <source>Digital zoom</source>
        <translation>Zoom digital</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="938"/>
        <source>Zoom</source>
        <translation>Zoom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="939"/>
        <source>Copy coordinates</source>
        <translation>Copiar coordenades</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="940"/>
        <source>Left Click</source>
        <translation>Clic esquerre</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="954"/>
        <location filename="../src/GUI/gui.cpp" line="972"/>
        <source>Map directory:</source>
        <translation>Directori de mapes:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="956"/>
        <location filename="../src/GUI/gui.cpp" line="974"/>
        <source>POI directory:</source>
        <translation>Directori de POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="958"/>
        <location filename="../src/GUI/gui.cpp" line="976"/>
        <source>CRS directory:</source>
        <translation>Directori CRS:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="960"/>
        <location filename="../src/GUI/gui.cpp" line="978"/>
        <source>DEM directory:</source>
        <translation>Directori DEM:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="962"/>
        <location filename="../src/GUI/gui.cpp" line="980"/>
        <source>Styles directory:</source>
        <translation>Directori d&apos;estils:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="964"/>
        <location filename="../src/GUI/gui.cpp" line="982"/>
        <source>Symbols directory:</source>
        <translation>Directori de simbologia:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="966"/>
        <location filename="../src/GUI/gui.cpp" line="984"/>
        <source>Tile cache directory:</source>
        <translation>Directori de la memòria cau de tessel·les:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="995"/>
        <location filename="../src/GUI/gui.cpp" line="998"/>
        <source>Open file</source>
        <translation>Obrir fitxer</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1030"/>
        <source>Open directory</source>
        <translation>Obrir directori</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1093"/>
        <source>Error loading data file:</source>
        <translation>Error en carregar fitxer de dades:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1096"/>
        <location filename="../src/GUI/gui.cpp" line="1208"/>
        <source>Line: %1</source>
        <translation>Línia: %1</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1101"/>
        <location filename="../src/GUI/gui.cpp" line="1778"/>
        <location filename="../src/GUI/gui.cpp" line="1878"/>
        <source>Don&apos;t show again</source>
        <translation>No ho tornis a mostrar</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1175"/>
        <location filename="../src/GUI/gui.cpp" line="1178"/>
        <source>Open POI file</source>
        <translation>Obrir fitxer POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1205"/>
        <source>Error loading POI file:</source>
        <translation>Error en carregar fitxer POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1352"/>
        <location filename="../src/GUI/gui.cpp" line="1410"/>
        <source>Tracks</source>
        <translation>Traces</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1354"/>
        <location filename="../src/GUI/gui.cpp" line="1412"/>
        <source>Routes</source>
        <translation>Rutes</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1356"/>
        <location filename="../src/GUI/gui.cpp" line="1414"/>
        <source>Waypoints</source>
        <translation>Punts de pas</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1358"/>
        <location filename="../src/GUI/gui.cpp" line="1416"/>
        <source>Areas</source>
        <translation>Àrees</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1362"/>
        <location filename="../src/GUI/gui.cpp" line="1364"/>
        <location filename="../src/GUI/gui.cpp" line="1421"/>
        <location filename="../src/GUI/gui.cpp" line="1423"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1385"/>
        <location filename="../src/GUI/gui.cpp" line="1388"/>
        <location filename="../src/GUI/gui.cpp" line="1389"/>
        <source>Statistics</source>
        <translation>Estadístiques</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1406"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1717"/>
        <location filename="../src/GUI/gui.cpp" line="1720"/>
        <source>Open map file</source>
        <translation>Obrir arxiu de mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1772"/>
        <location filename="../src/GUI/gui.cpp" line="1829"/>
        <location filename="../src/GUI/gui.cpp" line="1848"/>
        <location filename="../src/GUI/gui.cpp" line="1872"/>
        <source>Error loading map:</source>
        <translation>Error en carregar mapa:</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1912"/>
        <source>Select map directory</source>
        <translation>Escollir directori de mapes</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1941"/>
        <source>Clear &quot;%1&quot; tile cache?</source>
        <translation>Buidar &quot;%1&quot;memòria cau de tessel·les?</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1961"/>
        <source>DEM tiles download limit exceeded. If you really need data for such a huge area, download the files manually.</source>
        <translation>S&apos;ha superat el límit de descàrrega de tessel·les DEM. Si realment necessiteu dades per a una àrea tan gran, descarregueu els fitxers manualment.</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="1964"/>
        <source>Download %n DEM tiles?</source>
        <translation>
            <numerusform>Descarregar %n tessel·la DEM?</numerusform>
            <numerusform>Descarregar %n tessel·les DEM?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1977"/>
        <source>Could not download all required DEM files.</source>
        <translation>No s&apos;ha pogut descarregar tots els fitxers DEM necessaris.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="1997"/>
        <source>No local DEM tiles found.</source>
        <translation>No s&apos;ha trobat tessel·les DEM locals.</translation>
    </message>
    <message>
        <location filename="../src/GUI/gui.cpp" line="2011"/>
        <source>No files loaded</source>
        <translation>Cap fitxer carregat</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/GUI/gui.cpp" line="2015"/>
        <source>%n files</source>
        <translation>
            <numerusform>%n fitxer</numerusform>
            <numerusform>%n fitxers</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GearRatioGraph</name>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="12"/>
        <location filename="../src/GUI/gearratiograph.h" line="17"/>
        <source>Gear ratio</source>
        <translation>Relació de transmissió</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="28"/>
        <source>Top</source>
        <translation>Superior</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="30"/>
        <source>Min</source>
        <translation>Mín</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="32"/>
        <source>Max</source>
        <translation>Màx</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="35"/>
        <source>Most used</source>
        <translation>El més utilitzat</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Mínim</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiograph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Màxim</translation>
    </message>
</context>
<context>
    <name>GearRatioGraphItem</name>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="35"/>
        <source>Minimum</source>
        <translation>Mínim</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="36"/>
        <source>Maximum</source>
        <translation>Màxim</translation>
    </message>
    <message>
        <location filename="../src/GUI/gearratiographitem.cpp" line="37"/>
        <source>Most used</source>
        <translation>Més utilitzat</translation>
    </message>
</context>
<context>
    <name>GraphView</name>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="74"/>
        <source>Data not available</source>
        <translation>Sense dades</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="94"/>
        <location filename="../src/GUI/graphview.cpp" line="199"/>
        <source>Distance</source>
        <translation>Distància</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="131"/>
        <location filename="../src/GUI/graphview.cpp" line="139"/>
        <source>ft</source>
        <translation>peus</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="134"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="142"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="147"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="150"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="156"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="159"/>
        <source>min</source>
        <translation>mín</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="162"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="../src/GUI/graphview.cpp" line="201"/>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
</context>
<context>
    <name>HeartRateGraph</name>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="11"/>
        <source>bpm</source>
        <translation>ppm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="12"/>
        <location filename="../src/GUI/heartrategraph.h" line="16"/>
        <source>Heart rate</source>
        <translation>Ritme cardíac</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Màx</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Màxim</translation>
    </message>
</context>
<context>
    <name>HeartRateGraphItem</name>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Màxim</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="18"/>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="20"/>
        <source>bpm</source>
        <translation>ppm</translation>
    </message>
    <message>
        <location filename="../src/GUI/heartrategraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
</context>
<context>
    <name>MapItem</name>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="79"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/GUI/mapitem.cpp" line="81"/>
        <source>File</source>
        <translation>Fitxer</translation>
    </message>
</context>
<context>
    <name>MapList</name>
    <message>
        <location filename="../src/map/maplist.cpp" line="158"/>
        <source>Supported files</source>
        <translation>Fitxers compatibles</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="160"/>
        <source>Electronic Navigational Charts</source>
        <translation>Cartes Nàutiques Electròniques</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="162"/>
        <source>AlpineQuest maps</source>
        <translation>Mapes AlpineQuest</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="163"/>
        <source>GEMF maps</source>
        <translation>Mapes GEMF</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="164"/>
        <source>Garmin IMG maps</source>
        <translation>Mapes Garmin IMG</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="166"/>
        <source>Garmin JNX maps</source>
        <translation>Mapes Garmin JNX</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="167"/>
        <source>BSB nautical charts</source>
        <translation>Cartes nàutiques BSB</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="168"/>
        <source>KMZ maps</source>
        <translation>Mapes KMZ</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="169"/>
        <source>Mapsforge maps</source>
        <translation>Mapes Mapsforge</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="170"/>
        <source>OziExplorer maps</source>
        <translation>Mapes OziExplorer</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="171"/>
        <source>MBTiles maps</source>
        <translation>Mapes MBTiles</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="172"/>
        <source>Orux maps</source>
        <translation>Mapes Orux</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="173"/>
        <source>QuickChart maps</source>
        <translation>Mapes QuickChart</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="174"/>
        <source>TwoNav maps</source>
        <translation>Mapes TwoNav</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="175"/>
        <source>Osmdroid SQLite maps</source>
        <translation>Mapes Osmdroid SQL</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="176"/>
        <source>Locus/OsmAnd/RMaps SQLite maps</source>
        <translation>Mapes SQLite Locus/OsmAnd/Rmaps</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="178"/>
        <source>TrekBuddy maps/atlases</source>
        <translation>Mapes o atles TrekBuddy</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="180"/>
        <source>GeoTIFF images</source>
        <translation>Imatges GeoTIFF</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="181"/>
        <source>World-file georeferenced images</source>
        <translation>Imatges amb georeferenciació per worldfile</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="183"/>
        <source>Online map sources</source>
        <translation>Mapes en línia</translation>
    </message>
    <message>
        <location filename="../src/map/maplist.cpp" line="184"/>
        <source>All files</source>
        <translation>Tots els fitxers</translation>
    </message>
</context>
<context>
    <name>MotionInfoItem</name>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="87"/>
        <source>kn</source>
        <translation>nus</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="90"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="93"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="100"/>
        <source>ft/min</source>
        <translation>peus/min</translation>
    </message>
    <message>
        <location filename="../src/GUI/motioninfoitem.cpp" line="103"/>
        <source>m/min</source>
        <translation>m/min</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="70"/>
        <source>Select the proper coordinate reference system (CRS) of maps without a CRS definition (JNX, KMZ and World file maps).</source>
        <translation>Seleccioneu el sistema de referència de coordenades (CRS) adequat dels mapes sense un CRS definit (JNX, KMZ i fitxers World).</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="73"/>
        <source>Select the desired projection of vector maps (IMG, Mapsforge and ENC maps). The projection must be valid for the whole map area.</source>
        <translation>Seleccioneu la projecció desitjada de mapes vectorials (mapes IMG, Mapsforge i ENC). La projecció ha de ser vàlida per a tota l&apos;àrea del mapa.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="78"/>
        <source>Standard</source>
        <translation>Estàndard</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="83"/>
        <source>Non-HiDPI maps are loaded as HiDPI maps. The map is sharp but map objects are small/hard to read.</source>
        <translation>Els mapes que no són HiDPI es carreguen com a mapes HiDPI. El mapa es veu nítid però els objectes del mapa són petits/difícils de llegir.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="85"/>
        <source>Non-HiDPI maps are loaded such as they are. Map objects have the expected size but the map is blurry.</source>
        <translation>Els mapes que no són HiDPI es carreguen tal com estan. Els objectes del mapa tenen la mida esperada, però el mapa es veu borrós.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="95"/>
        <source>Input</source>
        <translation>Entrada</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="97"/>
        <source>Output</source>
        <translation>Sortida</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="104"/>
        <source>Input:</source>
        <translation>Entrada:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="107"/>
        <source>Output:</source>
        <translation>Sortida:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="128"/>
        <source>Projection</source>
        <translation>Projecció</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="129"/>
        <source>HiDPI display mode</source>
        <translation>Mode de visualització HiDPI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="139"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="146"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="152"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="220"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="227"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="265"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="628"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="163"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="267"/>
        <source>Use anti-aliasing</source>
        <translation>Utilitzar anti-aliasing</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="169"/>
        <source>Track width:</source>
        <translation>Amplada de traça:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="170"/>
        <source>Track style:</source>
        <translation>Estil de traça:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="172"/>
        <source>Route width:</source>
        <translation>Amplada de ruta:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="173"/>
        <source>Route style:</source>
        <translation>Estil de ruta:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="175"/>
        <source>Area border width:</source>
        <translation>Amplada de la vora de l&apos;àrea:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="176"/>
        <source>Area border style:</source>
        <translation>Estil de la vora de l&apos;àrea:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="177"/>
        <source>Area fill opacity:</source>
        <translation>Opacitat d&apos;ompliment de l&apos;àrea:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="179"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="202"/>
        <source>Base color:</source>
        <translation>Color base:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="180"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="203"/>
        <source>Palette shift:</source>
        <translation>Canvi de paleta:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="186"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="191"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="196"/>
        <source>Width:</source>
        <translation>Amplada:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="187"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="192"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="197"/>
        <source>Style:</source>
        <translation>Estil:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="188"/>
        <source>Tracks</source>
        <translation>Traces</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="193"/>
        <source>Routes</source>
        <translation>Rutes</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="199"/>
        <source>Areas</source>
        <translation>Àrees</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="235"/>
        <source>Waypoint color:</source>
        <translation>Color del punt de pas:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="236"/>
        <source>Waypoint size:</source>
        <translation>Mida del punt de pas:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="238"/>
        <source>POI color:</source>
        <translation>Color de POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="239"/>
        <source>POI size:</source>
        <translation>Mida de POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="243"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="248"/>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="244"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="249"/>
        <source>Size:</source>
        <translation>Mida:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="245"/>
        <source>Waypoints</source>
        <translation>Punts de pas</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="250"/>
        <source>POIs</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="273"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="279"/>
        <source>Line width:</source>
        <translation>Amplada de línia:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="274"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="280"/>
        <source>Slider color:</source>
        <translation>Color del control lliscant:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="301"/>
        <source>Info background</source>
        <translation>Informació de fons</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="305"/>
        <source>Background color:</source>
        <translation>Color de fons:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="307"/>
        <source>Crosshair color:</source>
        <translation>Color de la creu:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="308"/>
        <source>Info color:</source>
        <translation>Color de la informació:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="318"/>
        <source>Paths</source>
        <translation>Camins</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="319"/>
        <source>Points</source>
        <translation>Punts</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="320"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="757"/>
        <source>Graphs</source>
        <translation>Gràfics</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="321"/>
        <source>Map</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="328"/>
        <source>Moving average window size</source>
        <translation>Mida mitjana de la finestra en moviment</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="346"/>
        <source>Eliminate GPS outliers</source>
        <translation>Elimina els valors atípics del GPS</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="352"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="370"/>
        <source>Smoothing</source>
        <translation>Suavitzat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="353"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="363"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="480"/>
        <source>Elevation:</source>
        <translation>Elevació:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="354"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="364"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="479"/>
        <source>Speed:</source>
        <translation>Velocitat:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="355"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="365"/>
        <source>Heart rate:</source>
        <translation>Ritme cardíac:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="356"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="366"/>
        <source>Cadence:</source>
        <translation>Cadència:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="357"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="367"/>
        <source>Power:</source>
        <translation>Potència:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="380"/>
        <source>Automatic</source>
        <translation>Automàtic</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="381"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="431"/>
        <source>Custom</source>
        <translation>Personalitzat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="394"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="397"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="400"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="404"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="784"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="411"/>
        <source>Computed from distance/time</source>
        <translation>Calculat a partir de la distància/temps</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="412"/>
        <source>Recorded by device</source>
        <translation>Enregistrat amb dispositiu</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="417"/>
        <source>Show secondary speed</source>
        <translation>Mostra la velocitat secundària</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="420"/>
        <source>GPS data</source>
        <translation>Dades GPS</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="421"/>
        <source>DEM data</source>
        <translation>Dades DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="426"/>
        <source>Show secondary elevation</source>
        <translation>Mostra elevació secundària</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="429"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="430"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="835"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="886"/>
        <source>System</source>
        <translation>Sistema</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="450"/>
        <source>Use segments</source>
        <translation>Utilitzeu segments</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="481"/>
        <source>Time zone:</source>
        <translation>Fus horari:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="495"/>
        <source>Speed</source>
        <translation>Velocitat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="500"/>
        <source>Elevation</source>
        <translation>Elevació</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="506"/>
        <source>Time zone</source>
        <translation>Fus horari</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="527"/>
        <source>Minimal speed:</source>
        <translation>Velocitat mínima:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="528"/>
        <source>Minimal duration:</source>
        <translation>Durada mínima:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="539"/>
        <source>Sources</source>
        <translation>Fonts</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="540"/>
        <source>Filtering</source>
        <translation>Filtrat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="541"/>
        <source>Pause detection</source>
        <translation>Detecció d&apos;aturades</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="553"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="556"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="559"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="563"/>
        <source>Radius:</source>
        <translation>Radi:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="569"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="877"/>
        <source>POI</source>
        <translation>POI</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="586"/>
        <source>Use HTTP authentication</source>
        <translation>Utilitzeu l&apos;autenticació HTTP</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="592"/>
        <source>Use $lat and $lon for NYY/SYY and EXXX/WXXX in the URL.</source>
        <translation>Utilitzeu $lat i $lon per a NYY/SYY i EXXX/WXXX a l&apos;URL.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="597"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="610"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="198"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="306"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="644"/>
        <source>Opacity:</source>
        <translation>Opacitat:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="646"/>
        <source>Blur radius:</source>
        <translation>Radi de desenfocament:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="648"/>
        <source>Azimuth:</source>
        <translation>Azimut:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="649"/>
        <source>Altitude:</source>
        <translation>Altitud:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="650"/>
        <source>Z Factor:</source>
        <translation>Factor Z:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="655"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="689"/>
        <source>Source</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="656"/>
        <source>Hillshading</source>
        <translation>Ombrejat</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="676"/>
        <source>Plugin:</source>
        <translation>Connector:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="696"/>
        <source>WYSIWYG</source>
        <translation>WYSIWYG</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="77"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="697"/>
        <source>High-Resolution</source>
        <translation>Alta resolució</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="645"/>
        <source>Lightening:</source>
        <translation>Clarejar:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="702"/>
        <source>The printed area is approximately the display area. The map zoom level does not change.</source>
        <translation>L&apos;àrea impresa és aproximadament l&apos;àrea de visualització. El nivell de zoom del mapa no canvia.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="704"/>
        <source>The zoom level will be changed so that the whole content (tracks/waypoints) fits to the printed area and the map resolution is as close as possible to the print resolution.</source>
        <translation>El nivell de zoom es canviarà de manera que tot el contingut (traces/punts de pas) s&apos;ajusti a l&apos;àrea impresa i la resolució del mapa sigui el més propera possible a la resolució d&apos;impressió.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="720"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="722"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="724"/>
        <source>Distance</source>
        <translation>Distància</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="726"/>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="728"/>
        <source>Moving time</source>
        <translation>Temps en moviment</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="730"/>
        <source>Item count (&gt;1)</source>
        <translation>Recompte d&apos;elements (&gt;1)</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="745"/>
        <source>Separate graph page</source>
        <translation>Pàgina de gràfic separada</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="755"/>
        <source>Print mode</source>
        <translation>Mode d&apos;impressió</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="756"/>
        <source>Header</source>
        <translation>Capçalera</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="764"/>
        <source>Use OpenGL</source>
        <translation>Utilitzeu OpenGL</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="766"/>
        <source>Enable HTTP/2</source>
        <translation>Activeu HTTP/2</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="772"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="778"/>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="790"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="798"/>
        <source>Image cache size:</source>
        <translation>Mida de la memòria cau d&apos;imatges:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="792"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="800"/>
        <source>Connection timeout:</source>
        <translation>Temps d&apos;espera de connexió:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="791"/>
        <location filename="../src/GUI/optionsdialog.cpp" line="799"/>
        <source>DEM cache size:</source>
        <translation>Mida de la memòria cau MDE:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="819"/>
        <source>Select the initial paths of the file open dialogues. Leave the field empty for the system default.</source>
        <translation>Seleccioneu les rutes inicials dels diàlegs d&apos;obrir fitxers. Deixeu el camp buit per a l&apos;opció predeterminada del sistema.</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="823"/>
        <source>Data:</source>
        <translation>Dades:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="824"/>
        <source>Maps:</source>
        <translation>Mapes:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="825"/>
        <source>POI:</source>
        <translation>POI:</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="836"/>
        <source>Initial paths</source>
        <translation>Rutes inicials</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="872"/>
        <source>Appearance</source>
        <translation>Aspecte</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="874"/>
        <source>Maps</source>
        <translation>Mapes</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="876"/>
        <source>Data</source>
        <translation>Dades</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="879"/>
        <source>DEM</source>
        <translation>DEM</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="882"/>
        <source>Position</source>
        <translation>Posició</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="884"/>
        <source>Print &amp; Export</source>
        <translation>Imprimeix i exporta</translation>
    </message>
    <message>
        <location filename="../src/GUI/optionsdialog.cpp" line="919"/>
        <source>Options</source>
        <translation>Opcions</translation>
    </message>
</context>
<context>
    <name>PDFExportDialog</name>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>PDF files</source>
        <translation>Fitxers PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="28"/>
        <source>All files</source>
        <translation>Tots els fitxers</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="56"/>
        <source>Portrait</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="57"/>
        <source>Landscape</source>
        <translation>Apaïsat</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>cm</source>
        <translation>cm</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="67"/>
        <source>in</source>
        <translation>in</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="73"/>
        <source>Page Setup</source>
        <translation>Configuració de pàgina</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="76"/>
        <source>Page size:</source>
        <translation>Mida de la pàgina:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="77"/>
        <source>Resolution:</source>
        <translation>Resolució:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="78"/>
        <source>Orientation:</source>
        <translation>Orientació:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="79"/>
        <source>Margins:</source>
        <translation>Marges:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="85"/>
        <source>File:</source>
        <translation>Fitxer:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="92"/>
        <source>Output file</source>
        <translation>Fitxer de sortida</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="99"/>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="119"/>
        <source>Export to PDF</source>
        <translation>Exporta com PDF</translation>
    </message>
    <message>
        <location filename="../src/GUI/pdfexportdialog.cpp" line="127"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>PNGExportDialog</name>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>PNG files</source>
        <translation>Fitxers PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="25"/>
        <source>All files</source>
        <translation>Tots els fitxers</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="34"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="39"/>
        <location filename="../src/GUI/pngexportdialog.cpp" line="43"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="45"/>
        <source>Use anti-aliasing</source>
        <translation>Utilitzeu anti-aliasing</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="49"/>
        <source>Image Setup</source>
        <translation>Configuració de la imatge</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="52"/>
        <source>Image width:</source>
        <translation>Amplada de la imatge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="53"/>
        <source>Image height:</source>
        <translation>Alçada de la imatge:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="54"/>
        <source>Margins:</source>
        <translation>Marges:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="61"/>
        <source>File:</source>
        <translation>Fitxer:</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="68"/>
        <source>Output file</source>
        <translation>Fitxer de sortida</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="75"/>
        <source>Export</source>
        <translation>Exporta</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="95"/>
        <source>Export to PNG</source>
        <translation>Exporta com PNG</translation>
    </message>
    <message>
        <location filename="../src/GUI/pngexportdialog.cpp" line="103"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>PolygonItem</name>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="17"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/GUI/areaitem.cpp" line="19"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
</context>
<context>
    <name>PowerGraph</name>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="11"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="12"/>
        <location filename="../src/GUI/powergraph.h" line="16"/>
        <source>Power</source>
        <translation>Potència</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="30"/>
        <source>Max</source>
        <translation>Màx</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="33"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraph.cpp" line="35"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
</context>
<context>
    <name>PowerGraphItem</name>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="17"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="18"/>
        <location filename="../src/GUI/powergraphitem.cpp" line="20"/>
        <source>W</source>
        <translation>W</translation>
    </message>
    <message>
        <location filename="../src/GUI/powergraphitem.cpp" line="19"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
</context>
<context>
    <name>RouteItem</name>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="16"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="18"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="20"/>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="21"/>
        <source>Distance</source>
        <translation>Distància</translation>
    </message>
    <message>
        <location filename="../src/GUI/routeitem.cpp" line="32"/>
        <source>Links</source>
        <translation>Enllaços</translation>
    </message>
</context>
<context>
    <name>ScaleItem</name>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="108"/>
        <source>mi</source>
        <translation>mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="109"/>
        <location filename="../src/GUI/scaleitem.cpp" line="112"/>
        <source>ft</source>
        <translation>peus</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="111"/>
        <source>nmi</source>
        <translation>nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="114"/>
        <source>km</source>
        <translation>km</translation>
    </message>
    <message>
        <location filename="../src/GUI/scaleitem.cpp" line="115"/>
        <source>m</source>
        <translation>m</translation>
    </message>
</context>
<context>
    <name>SpeedGraph</name>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="15"/>
        <location filename="../src/GUI/speedgraph.h" line="18"/>
        <source>Speed</source>
        <translation>Velocitat</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="30"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="31"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="34"/>
        <source>Avg</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="36"/>
        <source>Max</source>
        <translation>Màx</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="39"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="41"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="44"/>
        <source>Pace</source>
        <translation>Ritme</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="133"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="136"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraph.cpp" line="139"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
</context>
<context>
    <name>SpeedGraphItem</name>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="23"/>
        <source>mi/h</source>
        <translation>mi/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>kn</source>
        <translation>kn</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="24"/>
        <source>km/h</source>
        <translation>km/h</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="27"/>
        <source>min/km</source>
        <translation>min/km</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/mi</source>
        <translation>min/mi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="28"/>
        <source>min/nmi</source>
        <translation>min/nmi</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="31"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="33"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/speedgraphitem.cpp" line="35"/>
        <source>Pace</source>
        <translation>Ritme</translation>
    </message>
</context>
<context>
    <name>TemperatureGraph</name>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="12"/>
        <location filename="../src/GUI/temperaturegraph.h" line="16"/>
        <source>Temperature</source>
        <translation>Temperatura</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="28"/>
        <source>Avg</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="30"/>
        <source>Min</source>
        <translation>Mín</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="32"/>
        <source>Max</source>
        <translation>Màx</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="35"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="37"/>
        <source>Minimum</source>
        <translation>Mínima</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="39"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="111"/>
        <source>C</source>
        <translation>ºC</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraph.cpp" line="115"/>
        <source>F</source>
        <translation>ºF</translation>
    </message>
</context>
<context>
    <name>TemperatureGraphItem</name>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>C</source>
        <translation>°C</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="21"/>
        <source>F</source>
        <translation>°F</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="24"/>
        <source>Average</source>
        <translation>Mitjana</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="26"/>
        <source>Maximum</source>
        <translation>Màxima</translation>
    </message>
    <message>
        <location filename="../src/GUI/temperaturegraphitem.cpp" line="28"/>
        <source>Minimum</source>
        <translation>Mínima</translation>
    </message>
</context>
<context>
    <name>TrackItem</name>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="15"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="17"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="19"/>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="20"/>
        <source>Distance</source>
        <translation>Distància</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="23"/>
        <source>Total time</source>
        <translation>Temps total</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="25"/>
        <source>Moving time</source>
        <translation>Temps en moviment</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="27"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/trackitem.cpp" line="38"/>
        <source>Links</source>
        <translation>Enllaços</translation>
    </message>
</context>
<context>
    <name>WaypointItem</name>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="25"/>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="26"/>
        <source>Coordinates</source>
        <translation>Coordenades</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="33"/>
        <source>Elevation</source>
        <translation>Elevació</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="36"/>
        <source>Date</source>
        <translation>Data</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="40"/>
        <source>Description</source>
        <translation>Descripció</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="44"/>
        <source>Comment</source>
        <translation>Comentari</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="47"/>
        <source>Symbol</source>
        <translation>Símbol</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="52"/>
        <source>Address</source>
        <translation>Adreça</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="55"/>
        <source>Phone</source>
        <translation>Telèfon</translation>
    </message>
    <message>
        <location filename="../src/GUI/waypointitem.cpp" line="65"/>
        <source>Links</source>
        <translation>Enllaços</translation>
    </message>
</context>
</TS>
